@@ -139,6 +139,11 @@ void ObjectPad_extend_pad_vars(pTHX_ const ClassMeta *meta);
 #define get_field_for_padix(padix)  ObjectPad_get_field_for_padix(aTHX_ padix)
 FieldMeta *ObjectPad_get_field_for_padix(pTHX_ PADOFFSET padix);
 
+enum {
+  /* Common flags for newMETHSTARTOP, newFIELDPADOP and newFIELDSVOP */
+  OPfMETHSTART_ROLE = (1 << 16),
+};
+
 #define newMETHSTARTOP(flags)  ObjectPad_newMETHSTARTOP(aTHX_ flags)
 OP *ObjectPad_newMETHSTARTOP(pTHX_ U32 flags);
 
@@ -184,6 +189,9 @@ void ObjectPad_mop_class_set_superclass(pTHX_ ClassMeta *class, SV *superclassna
 #define mop_class_inherit_from_superclass(class, args, nargs)  ObjectPad_mop_class_inherit_from_superclass(aTHX_ class, args, nargs)
 void ObjectPad_mop_class_inherit_from_superclass(pTHX_ ClassMeta *class, SV **args, size_t nargs);
 
+#define mop_class_prepare_parse(class)  ObjectPad_mop_class_prepare_parse(aTHX_ class)
+void ObjectPad_mop_class_prepare_parse(pTHX_ ClassMeta *meta);
+
 #define mop_class_begin(meta)  ObjectPad_mop_class_begin(aTHX_ meta)
 void ObjectPad_mop_class_begin(pTHX_ ClassMeta *meta);
 
